From 47c37b4d634d834287c5cc1da948e643d61b0847 Mon Sep 17 00:00:00 2001
From: Lev Babiev <harley@hosers.org>
Date: Fri, 24 Mar 2023 07:44:07 +0000
Subject: [PATCH] network: guard against NULL dereference

---
 modules/network.c | 39 ++++++++++++++++++++++-----------------
 1 file changed, 22 insertions(+), 17 deletions(-)

diff --git a/modules/network.c b/modules/network.c
index 44d0d5e..7841570 100644
--- a/modules/network.c
+++ b/modules/network.c
@@ -73,23 +73,28 @@ static void net_update_ifaddrs ( void )
   for(iter=addrs;iter;iter=iter->ifa_next)
   {
     iface = net_iface_from_name(iter->ifa_name,TRUE);
-    switch(iter->ifa_addr->sa_family)
-    {
-      case AF_INET:
-        iface->ip = ((struct sockaddr_in *)(iter->ifa_addr))->sin_addr;
-        if(iter->ifa_netmask)
-          iface->mask = ((struct sockaddr_in *)(iter->ifa_netmask))->sin_addr;
-        if(iter->ifa_broadaddr)
-          iface->bcast = ((struct sockaddr_in *)(iter->ifa_broadaddr))->sin_addr;
-        break;
-      case AF_INET6:
-        iface->ip6 = ((struct sockaddr_in6 *)(iter->ifa_addr))->sin6_addr;
-        if(iter->ifa_netmask)
-          iface->mask6 = ((struct sockaddr_in6 *)(iter->ifa_netmask))->sin6_addr;
-        if(iter->ifa_broadaddr)
-          iface->bcast6 = ((struct sockaddr_in6 *)(iter->ifa_broadaddr))->sin6_addr;
-        break;
-    }
+    if(iter->ifa_addr)
+      switch(iter->ifa_addr->sa_family)
+      {
+        case AF_INET:
+          iface->ip = ((struct sockaddr_in *)(iter->ifa_addr))->sin_addr;
+          if(iter->ifa_netmask)
+            iface->mask =
+              ((struct sockaddr_in *)(iter->ifa_netmask))->sin_addr;
+          if(iter->ifa_broadaddr)
+            iface->bcast =
+              ((struct sockaddr_in *)(iter->ifa_broadaddr))->sin_addr;
+          break;
+        case AF_INET6:
+          iface->ip6 = ((struct sockaddr_in6 *)(iter->ifa_addr))->sin6_addr;
+          if(iter->ifa_netmask)
+            iface->mask6 =
+              ((struct sockaddr_in6 *)(iter->ifa_netmask))->sin6_addr;
+          if(iter->ifa_broadaddr)
+            iface->bcast6 =
+              ((struct sockaddr_in6 *)(iter->ifa_broadaddr))->sin6_addr;
+          break;
+      }
   }
   freeifaddrs(addrs);
 }
